@@ -9,9 +9,20 @@ Net::ISC::DHCPd::Config::Group - Group config parameter
 See L<Net::ISC::DHCPd::Config::Role> for methods and attributes without
 documentation.
 
+An instance from this class, comes from / will produce:
+
+    group {
+        $keyvalues_attribute_value
+        $options_attribute_value
+        $hosts_attribute_value
+        $groups_attribute_value
+        $sharednetworks_attribute_value
+        $subnets_attribute_value
+    }
+
 =head1 SYNOPSIS
 
-See L<Net::ISC::DHCPd::Config> for synopsis.
+See L<Net::ISC::DHCPd::Config/SYNOPSIS>.
 
 =cut
 
@@ -20,6 +31,9 @@ use Moose;
 with 'Net::ISC::DHCPd::Config::Role';
 
 __PACKAGE__->create_children(qw/
+    Net::ISC::DHCPd::Config::Subnet
+    Net::ISC::DHCPd::Config::SharedNetwork
+    Net::ISC::DHCPd::Config::Group
     Net::ISC::DHCPd::Config::Host
     Net::ISC::DHCPd::Config::Option
     Net::ISC::DHCPd::Config::KeyValue
@@ -31,6 +45,14 @@ __PACKAGE__->create_children(qw/
 
 A list of parsed L<Net::ISC::DHCPd::Config::Subnet> objects.
 
+=head2 sharednetworks
+
+A list of parsed L<Net::ISC::DHCPd::Config::SharedNetwork> objects.
+
+=head2 groups
+
+A list of parsed L<Net::ISC::DHCPd::Config::Group> objects.
+
 =head2 hosts
 
 A list of parsed L<Net::ISC::DHCPd::Config::Host> objects.
@@ -39,10 +61,16 @@ A list of parsed L<Net::ISC::DHCPd::Config::Host> objects.
 
 A list of parsed L<Net::ISC::DHCPd::Config::Option> objects.
 
+=head2 keyvalues
+
+A list of parsed L<Net::ISC::DHCPd::Config::KeyValue> objects.
+
 =cut
 
 sub _build_regex { qr{^ \s* group}x }
 
+=head1 METHODS
+
 =head2 generate
 
 See L<Net::ISC::DHCPd::Config::Role/generate>.
